# Get involved
Whether you are a first-time contributor or open-source veteran, we welcome any contribution to the `molfeat` package. 
Your contributions help to make sure this package can remain free-to-use and open-source.

## Contribute
The most straight-forward way to contribute is through Github. In short, you can help by: 

- :star: **Star** the repository on Github.
- :computer: **Fix** existing code issues. 
- :bug: **Report** bugs or **request** new features. 
- :question: **Answer** questions of - and **interact** with - community members.
- :books: Improve **existing documentation** or add **new tutorials**.

To learn more about this, please see the [Developers documentation](../developers/contribute.md).


## Slack
[![slack](https://img.shields.io/badge/Join%20our%20Slack-4A154B?style=for-the-badge&logo=slack&logoColor=white)](https://join.slack.com/t/m2d2group/shared_invite/zt-16w1rjqqs-n81TiK~iB23XbZ0QWMYs~A)

The molfeat community is part of the [M2D2 community](https://m2d2.io). To orchestrate these efforts the `#molfeat` channel 
was created in the M2D2 Slack. Similar to a forum, this channel allows people to ask questions, make suggestions, 
showcase your work or discuss new features. 

## Datamol.io
Molfeat is part of the [datamol.io](https://datamol.io/) ecosystem. If you enjoy molfeat, consider giving our other
tools a look as well. These tools are designed to be synergetic and have complementary features.
